@@ -35,7 +35,7 @@ dialog_definition = r"""
     <property name="window_position">center</property>
     <property name="type_hint">dialog</property>
     <child internal-child="vbox">
-      <object class="GtkBox">
+      <object class="GtkBox" id="entry_box">
         <property name="spacing">6</property>
         <property name="border_width">6</property>
         <child>
@@ -50,7 +50,7 @@ dialog_definition = r"""
           </object>
         </child>
         <child internal-child="action_area">
-          <object class="GtkButtonBox">
+          <object class="GtkButtonBox" id="action_box">
             <child>
               <object class="GtkButton" id="cancel_button">
                 <property name="label">gtk-cancel</property>
@@ -89,7 +89,8 @@ def password_dialog(title, message):
     :raises RuntimeError: if Gtk can not be properly initialized
     """
     require_Gtk()
-    builder = Gtk.Builder.new_from_string(dialog_definition, -1)
+    builder = Gtk.Builder.new()
+    builder.add_from_string (dialog_definition)
     dialog = builder.get_object('entry_dialog')
     label = builder.get_object('message')
     entry = builder.get_object('entry')
@@ -124,22 +125,26 @@ def get_password_tty(device):
 
 
 def password(hint_gui):
+
     """
     Create a password prompt function.
 
     :param bool hint_gui: whether a GUI input dialog should be preferred
     """
+
     def gui():
         try:
             require_Gtk()
             return get_password_gui
         except RuntimeError:
             return None
+
     def tty():
         if sys.stdin.isatty():
             return get_password_tty
         else:
             return None
+
     if hint_gui:
         return gui() or tty()
     else:
@@ -147,6 +152,7 @@ def password(hint_gui):
 
 
 def browser(browser_name='xdg-open'):
+
     """
     Create a browse-directory function.
 
@@ -154,6 +160,7 @@ def browser(browser_name='xdg-open'):
     :returns: one-parameter open function
     :rtype: callable
     """
+
     if not browser_name:
         return None
     executable = find_executable(browser_name)
@@ -165,6 +172,8 @@ def browser(browser_name='xdg-open'):
               "You may want to change the value for the '-b' option.",
               browser_name))
         return None
+
     def browse(path):
         return subprocess.Popen([executable, path])
+
     return browse
